"""add CAPO_PATH env var to download and calibration

Revision ID: c4001510507c
Revises: 2b6e18877c8e
Create Date: 2021-05-21 10:02:03.013963

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "c4001510507c"
down_revision = "2b6e18877c8e"
branch_labels = None
depends_on = None


def upgrade():
    submit_file_content = """executable = test_download.sh
arguments = {{product_locator}} {{request_id}}

output = test_download.out
error = test_download.err
log = test_download.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/deliver

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue
"""

    op.execute(
        "UPDATE workflow_templates "
        f"SET content = E'{submit_file_content}' "
        "WHERE filename = 'test_download.condor'"
    )

    submit_file_contents = """executable = std_calibration.sh
arguments = {{product_locator}} {{request_id}} metadata.json PPR.xml

output = calibration.out
error = calibration.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/deliver-cipl.sh, ./PPR.xml, ./metadata.json

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue
"""
    op.execute(
        f"UPDATE workflow_templates SET content = E'{submit_file_contents}' WHERE filename = 'std_calibration.condor'"
    )


def downgrade():
    submit_file_content = """executable = test_download.sh
arguments = {{product_locator}} {{request_id}}

output = test_download.out
error = test_download.err
log = test_download.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/deliver

getenv = True

queue 
"""

    op.execute(
        "UPDATE workflow_templates "
        f"SET content = E'{submit_file_content}' "
        "WHERE filename = 'test_download.condor'"
    )

    submit_file_contents = """executable = std_calibration.sh
arguments = {{product_locator}} {{request_id}} metadata.json PPR.xml

output = calibration.out
error = calibration.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/deliver-cipl.sh

getenv = True

queue
"""
    op.execute(
        f"UPDATE workflow_templates SET content = E'{submit_file_contents}' WHERE filename = 'std_calibration.condor'"
    )
